Faster all-pairs shortest paths on a weighted graph
Compute all-pairs shortest-path distances of a 352-node undirected weighted graph faster than SciPy's Dijkstra-based shortest_path.
| # | Route | Speed-up over the reference implementation (×) ↑ | vs baseline |
|---|---|---|---|
| — | Baseline · Reference implementation | 1 | the bars start here |